########################
AutoQASM
########################

**AutoQASM is not an officially supported AWS product.**

This experimental module offers a new quantum-imperative programming experience embedded in Python
for developing quantum programs. AutoQASM is *experimental* software. We may change, remove, or
deprecate parts of the AutoQASM API without notice. The name AutoQASM is a working title and is
also subject to change.

This documentation provides information about the AutoQASM library. The project
is hosted on GitHub at https://github.com/amazon-braket/autoqasm. The project
includes the source code, installation instructions, and other information.


*****************************
Getting Started with AutoQASM
*****************************

For details on how to get started with AutoQASM, see the project
readme at https://github.com/amazon-braket/autoqasm/blob/main/README.md.


*******************
AutoQASM Decorators
*******************

For details on usage of AutoQASM decorators such as `@aq.main`, `@aq.subroutine`, `@aq.gate`,
and `@aq.gate_calibration`, see the decorators documentation at
https://github.com/amazon-braket/autoqasm/blob/main/doc/decorators.md.

For details on using AutoQASM with Amazon Braket Hybrid Jobs with the `@aq.hybrid_job` decorator,
see the documentation at https://github.com/amazon-braket/autoqasm/blob/main/doc/hybrid_jobs.md


********
Examples
********

There are several example notebooks available in the AutoQASM repo at
https://github.com/amazon-braket/autoqasm/tree/main/examples.


**************************
AutoQASM API Documentation
**************************

.. toctree::
    :maxdepth: 2

    _apidoc/modules
